==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/content/messages/ru/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Может быть видно не только участникам сообщества)',
    '<strong>Delete</strong> content?' => '<strong>Удалить</strong> запись?',
    '<strong>Move</strong> content' => '<strong>Перемещение</strong> содержимого',
    '<strong>Permalink</strong> to this post' => '<strong>Постоянная ссылка</strong> для этой записи',
    '<strong>Scheduling</strong> Options' => '<strong>Параметры расписания</strong>',
    'Activate scheduling' => 'Включить расписание',
    'Add a member to notify' => 'Добавить участника для уведомления',
    'Add tag...' => 'Добавить метку...',
    'Archived' => 'В архиве',
    'Attach Files' => 'Загрузить фотографию или файл',
    'Back to stream' => 'Вернуться в ленту',
    'Cancel' => 'Отменить',
    'Cancel Edit' => 'Отменить Редактирование',
    'Cannot notify the author.' => 'Не могу уведомить автора.',
    'Change to "Private"' => 'Сделать приватной',
    'Change to "Public"' => 'Сделать публичной',
    'Comments are locked' => 'Комментарии заблокированы',
    'Comments are unlocked' => 'Комментарии разблокированы',
    'Configure' => 'Настройки',
    'Confirm' => 'Подтвердить',
    'Content' => 'Содержимое',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Тег содержимого с неверным contentcontainer_id.',
    'Content has been moved to {spacename}' => 'Запись была перемещена в {spacename}',
    'Could not find requested content!' => 'Не удалось найти запрашиваемую запись!',
    'Create as draft' => 'Создать как черновик',
    'Created at:' => 'Создан в:',
    'Created by me' => 'Созданные мной',
    'Creation time' => 'Время создания',
    'Delete' => 'Удалить',
    'Deleted' => 'Удалить',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Вы хотите удалить эти записи, включая все комментарии и вложения?<br><br>Обратите внимание: если запись потока была создана с использованием модуля, исходный контент, с которым связана эта запись, также будет удален.',
    'Draft' => 'Черновик',
    'Edit' => 'Редактировать',
    'Enable' => 'Включить',
    'Enabled' => 'Включен',
    'Filter' => 'Фильтр',
    'Hidden' => 'Скрытый',
    'I\'m involved' => 'Где я участвую',
    'Invalid content id given!' => 'Неправильный id записи',
    'Invalid request method!' => 'Неверный метод запроса!',
    'Invalid space selection.' => 'Неправильный выбор сообщества.',
    'Last update' => 'Последнее обновление',
    'Last updated {time}' => 'Обновлено: {time}',
    'Load more' => 'Показать еще',
    'Lock comments' => 'Блокировка комментариев',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Уже закреплено максимальное количество записей!<br>Одновременно можно закрепить не более {count,plural,one{# записи} other{# записей}}',
    'Move content' => 'Переместить запись',
    'Move to archive' => 'Переместить в архив',
    'New Updates Available!' => 'Доступны новые обновления!',
    'No matches with your selected filters!' => 'Ничего не найдено. Попробуйте изменить фильтры!',
    'No tags found for the given query' => 'По данному запросу метки не найдены',
    'None' => 'Ничего',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Примечание: По техническим причинам возможна задержка на несколько минут.',
    'Nothing here yet!' => 'Здесь ничего еще нет!',
    'Notify members' => 'Уведомлять пользователей',
    'Permalink' => 'Постоянная ссылка',
    'Pin to top' => 'Закрепить вначале',
    'Pinned' => 'Закреплено',
    'Private' => 'Закрытые сообщества',
    'Public' => 'Публичная запись',
    'Publish draft' => 'Опубликовать черновик',
    'Save as draft' => 'Сохранить как черновик',
    'Save scheduling' => 'Сохранить расписание',
    'Schedule publication' => 'Запланировать публикацию',
    'Scheduled for {dateTime}' => 'Запланировано на {dateTime}',
    'Select type...' => 'Выберите тип...',
    'Specify who can see this content.' => 'Укажите, кто может видеть эту запись.',
    'Submit' => 'Отправить',
    'Tag' => 'Тег',
    'Target Space' => 'Сообщество - назначение',
    'The author of this content is not allowed to create private content within the selected space.' => 'Автор этого контента не имеет права создавать приватный записи в выбранном сообществе.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Автор этого контента не имеет права создавать публичный записи в выбранном сообществе.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Автору не разрешено создавать записи такого типа в этом сообществе.',
    'The content can\'t be moved to its current space.' => 'Запись не может быть перемещен в его текущее сообщество.',
    'The content cannot be published!' => 'Сообщение не может быть опубликовано!',
    'The content has been archived.' => 'Запись заархивирована.',
    'The content has been deleted.' => 'Запись удалена.',
    'The content has been successfully published.' => 'Содержимое успешно опубликовано.',
    'The content has been unarchived.' => 'Запись разархивирована.',
    'The given name is already in use.' => 'Данное имя уже используется.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Модуль {moduleName} не включен в выбранном сообществе.',
    'This action is disabled!' => 'Это действие отключено!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Этот тип записей не может быть перемещен из-за отсутствия настройки идентификатора модуля.',
    'This content type can\'t be moved.' => 'Этот тип записей не может быть перемещен.',
    'This space is archived.' => 'Это сообщество архивировано',
    'This space is not visible!' => 'Это сообщество не видно!',
    'Topics' => 'Темы',
    'Turn off notifications' => 'Отключить уведомления',
    'Turn on notifications' => 'Включить уведомления',
    'Unarchive' => 'Извлечь из архива',
    'Unlock comments' => 'Разблокировать комментарии',
    'Unpin' => 'Открепить',
    'Updated' => 'Обновлено',
    'Visible also to unregistered users' => 'Видимо также незарегистрированным пользователям',
    'Visible only to you' => 'Видимо только вам',
    'Visible to all Space members' => 'Видимо участникам сообщества',
    'Visible to all signed in users' => 'Видимо зарегистрированным пользователям',
    'Visible to friends of {displayName}' => 'Видимо друзьям {displayName}',
    'Visible to you and {displayName}' => 'Видимо вам и друзьям {displayName}',
    'Visible to your friends' => 'Видимо вашим друзьям',
    'With attachments' => 'С прикреплёнными файлами',
    'You cannot block the space owner!' => 'Вы не можете заблокировать владельца пространства!',
    'You cannot block the user of the same container!' => 'Вы не можете заблокировать пользователя одного и того же контейнера!',
    'You cannot block yourself!' => 'Вы не можете заблокировать себя!',
    'You do not have the permission to move this content to the given space.' => 'У вас нет разрешения перемещать эту запись в указанное место.',
    'You do not have the permission to move this content.' => 'У Вас нет разрешения на перемещение этой записиккон.',
    'Your last edit state has been saved!' => 'Последнее состояние сохранено.',
    'in' => 'в',
    'Advanced Content Search' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/content/messages/ru/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Может быть видно не только участникам сообщества)',
    '<strong>Delete</strong> content?' => '<strong>Удалить</strong> запись?',
    '<strong>Move</strong> content' => '<strong>Перемещение</strong> содержимого',
    '<strong>Permalink</strong> to this post' => '<strong>Постоянная ссылка</strong> для этой записи',
    '<strong>Scheduling</strong> Options' => '<strong>Параметры расписания</strong>',
    'Activate scheduling' => 'Включить расписание',
    'Add a member to notify' => 'Добавить участника для уведомления',
    'Add tag...' => 'Добавить метку...',
    'Advanced Content Search' => 'Расширенный поиск содержимого',
    'Archived' => 'В архиве',
    'Attach Files' => 'Загрузить фотографию или файл',
    'Back to stream' => 'Вернуться в ленту',
    'Cancel' => 'Отменить',
    'Cancel Edit' => 'Отменить Редактирование',
    'Cannot notify the author.' => 'Не могу уведомить автора.',
    'Change to "Private"' => 'Сделать приватной',
    'Change to "Public"' => 'Сделать публичной',
    'Comments are locked' => 'Комментарии заблокированы',
    'Comments are unlocked' => 'Комментарии разблокированы',
    'Configure' => 'Настройки',
    'Confirm' => 'Подтвердить',
    'Content' => 'Содержимое',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Тег содержимого с неверным contentcontainer_id.',
    'Content has been moved to {spacename}' => 'Запись была перемещена в {spacename}',
    'Could not find requested content!' => 'Не удалось найти запрашиваемую запись!',
    'Create as draft' => 'Создать как черновик',
    'Created at:' => 'Создан в:',
    'Created by me' => 'Созданные мной',
    'Creation time' => 'Время создания',
    'Delete' => 'Удалить',
    'Deleted' => 'Удалить',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Вы хотите удалить эти записи, включая все комментарии и вложения?<br><br>Обратите внимание: если запись потока была создана с использованием модуля, исходный контент, с которым связана эта запись, также будет удален.',
    'Draft' => 'Черновик',
    'Edit' => 'Редактировать',
    'Enable' => 'Включить',
    'Enabled' => 'Включен',
    'Filter' => 'Фильтр',
    'Hidden' => 'Скрытый',
    'I\'m involved' => 'Где я участвую',
    'Invalid content id given!' => 'Неправильный id записи',
    'Invalid request method!' => 'Неверный метод запроса!',
    'Invalid space selection.' => 'Неправильный выбор сообщества.',
    'Last update' => 'Последнее обновление',
    'Last updated {time}' => 'Обновлено: {time}',
    'Load more' => 'Показать еще',
    'Lock comments' => 'Блокировка комментариев',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Уже закреплено максимальное количество записей!<br>Одновременно можно закрепить не более {count,plural,one{# записи} other{# записей}}',
    'Move content' => 'Переместить запись',
    'Move to archive' => 'Переместить в архив',
    'New Updates Available!' => 'Доступны новые обновления!',
    'No matches with your selected filters!' => 'Ничего не найдено. Попробуйте изменить фильтры!',
    'No tags found for the given query' => 'По данному запросу метки не найдены',
    'None' => 'Ничего',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Примечание: По техническим причинам возможна задержка на несколько минут.',
    'Nothing here yet!' => 'Здесь ничего еще нет!',
    'Notify members' => 'Уведомлять пользователей',
    'Permalink' => 'Постоянная ссылка',
    'Pin to top' => 'Закрепить вначале',
    'Pinned' => 'Закреплено',
    'Private' => 'Закрытые сообщества',
    'Public' => 'Публичная запись',
    'Publish draft' => 'Опубликовать черновик',
    'Save as draft' => 'Сохранить как черновик',
    'Save scheduling' => 'Сохранить расписание',
    'Schedule publication' => 'Запланировать публикацию',
    'Scheduled for {dateTime}' => 'Запланировано на {dateTime}',
    'Select type...' => 'Выберите тип...',
    'Specify who can see this content.' => 'Укажите, кто может видеть эту запись.',
    'Submit' => 'Отправить',
    'Tag' => 'Тег',
    'Target Space' => 'Сообщество - назначение',
    'The author of this content is not allowed to create private content within the selected space.' => 'Автор этого контента не имеет права создавать приватный записи в выбранном сообществе.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Автор этого контента не имеет права создавать публичный записи в выбранном сообществе.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Автору не разрешено создавать записи такого типа в этом сообществе.',
    'The content can\'t be moved to its current space.' => 'Запись не может быть перемещен в его текущее сообщество.',
    'The content cannot be published!' => 'Сообщение не может быть опубликовано!',
    'The content has been archived.' => 'Запись заархивирована.',
    'The content has been deleted.' => 'Запись удалена.',
    'The content has been successfully published.' => 'Содержимое успешно опубликовано.',
    'The content has been unarchived.' => 'Запись разархивирована.',
    'The given name is already in use.' => 'Данное имя уже используется.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Модуль {moduleName} не включен в выбранном сообществе.',
    'This action is disabled!' => 'Это действие отключено!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Этот тип записей не может быть перемещен из-за отсутствия настройки идентификатора модуля.',
    'This content type can\'t be moved.' => 'Этот тип записей не может быть перемещен.',
    'This space is archived.' => 'Это сообщество архивировано',
    'This space is not visible!' => 'Это сообщество не видно!',
    'Topics' => 'Темы',
    'Turn off notifications' => 'Отключить уведомления',
    'Turn on notifications' => 'Включить уведомления',
    'Unarchive' => 'Извлечь из архива',
    'Unlock comments' => 'Разблокировать комментарии',
    'Unpin' => 'Открепить',
    'Updated' => 'Обновлено',
    'Visible also to unregistered users' => 'Видимо также незарегистрированным пользователям',
    'Visible only to you' => 'Видимо только вам',
    'Visible to all Space members' => 'Видимо участникам сообщества',
    'Visible to all signed in users' => 'Видимо зарегистрированным пользователям',
    'Visible to friends of {displayName}' => 'Видимо друзьям {displayName}',
    'Visible to you and {displayName}' => 'Видимо вам и друзьям {displayName}',
    'Visible to your friends' => 'Видимо вашим друзьям',
    'With attachments' => 'С прикреплёнными файлами',
    'You cannot block the space owner!' => 'Вы не можете заблокировать владельца пространства!',
    'You cannot block the user of the same container!' => 'Вы не можете заблокировать пользователя одного и того же контейнера!',
    'You cannot block yourself!' => 'Вы не можете заблокировать себя!',
    'You do not have the permission to move this content to the given space.' => 'У вас нет разрешения перемещать эту запись в указанное место.',
    'You do not have the permission to move this content.' => 'У Вас нет разрешения на перемещение этой записиккон.',
    'Your last edit state has been saved!' => 'Последнее состояние сохранено.',
    'in' => 'в',
    '(Also visible to people who are not logged in)' => '',
    'Topic already exists globally.' => '',
    'Topic already in use in Spaces or on Profiles.' => '',
];
